@@ -44,4 +44,4 @@ FUNCTIONS_DIR_NAME = "functions"
 # Connect
 
 CONNECT_URL = os.environ.get("CONNECT_URL", "http://localhost:8083")
-CONNECT_CONFIG_TEMPLATE = "connect_config.json.j2"
+POSTGRES_SOURCE_CONNECTOR_TEMPLATE = "postgres_source_connector.json.j2"
