@@ -1,6 +1,7 @@
 from typing import Iterator, Tuple
 
 import fire
+from colorama import Fore, deinit, init
 from psycopg2 import ProgrammingError, connect, sql
 from psycopg2.extras import RealDictCursor
 from requests import HTTPError
@@ -153,14 +154,20 @@ class Cli:
         cursor = conn.cursor(name="curname")
         cursor.itersize = CURSOR_ITERSIZE
         try:
+            # Function in order to filter ANSI escape sequences on Windows
+            # see https://pypi.org/project/colorama/
+            init(autoreset=True)
             for _id, resource in get_resources_from_model(cursor, model, offset, limit):
                 fhir = FhirResource(resource)
                 number_print(repr(fhir))
                 try:
                     fhir.validate()
-                    log.info(f"\U0001F525 resource (id={_id}) is valid")
+                    # The message will be printed in GREEN, hence the weird sequence
+                    # at the beginning and at the end
+                    log.info(f"{Fore.GREEN}✅ FHIR resource (id={_id}) is valid")
                 except FhirValidationError as e:
-                    log.error(e)
+                    # Same as above
+                    log.error(f"{Fore.RED}❌ FHIR resource (id={_id}) is not valid\n{e}")
                 input("Press [Return] for the next result or [Ctrl+c] to quit")
         except ProgrammingError as e:
             conn.rollback()
@@ -172,6 +179,9 @@ class Cli:
         finally:
             cursor.close()
             conn.close()
+            # Stop using Colorama
+            # see https://pypi.org/project/colorama/
+            deinit()
 
 
 def run():
